| Copyright | (c) Dominik Schrempf 2020 |
|---|---|
| License | GPL-3.0-or-later |
| Maintainer | dominik.schrempf@gmail.com |
| Stability | unstable |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
TLynx.Parsers
Description
Creation date: Wed Apr 22 13:34:35 2020.
Synopsis
- data NewickFormat
- newickFormat :: Parser NewickFormat
- newickHelp :: [String]
Documentation
data NewickFormat #
Newick tree format.
>>>unlines $ map (("- " <>) . description) (allValues :: [NewickFormat])- Standard: Branch support values are stored in square brackets after branch lengths. - IqTree: Branch support values are stored as node names after the closing bracket of forests. - RevBayes: Key-value pairs is provided in square brackets after node names as well as branch lengths. XXX: Key value pairs are ignored at the moment.
Instances
newickFormat :: Parser NewickFormat Source #
Parse NewickFormat.
newickHelp :: [String] Source #
Help for different NewickFormats.